==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/eo.php <==
<?php

return [
    'Names' => [
        'aa' => 'afara',
        'ab' => 'abĥaza',
        'af' => 'afrikansa',
        'am' => 'amhara',
        'ar' => 'araba',
        'as' => 'asama',
        'ay' => 'ajmara',
        'az' => 'azerbajĝana',
        'ba' => 'baŝkira',
        'be' => 'belorusa',
        'bg' => 'bulgara',
        'bi' => 'bislamo',
        'bn' => 'bengala',
        'bo' => 'tibeta',
        'br' => 'bretona',
        'bs' => 'bosnia',
        'ca' => 'kataluna',
        'co' => 'korsika',
        'cs' => 'ĉeĥa',
        'cy' => 'kimra',
        'da' => 'dana',
        'de' => 'germana',
        'dv' => 'mahla',
        'dz' => 'dzonko',
        'efi' => 'ibibioefika',
        'el' => 'greka',
        'en' => 'angla',
        'eo' => 'esperanto',
        'es' => 'hispana',
        'et' => 'estona',
        'eu' => 'eŭska',
        'fa' => 'persa',
        'fi' => 'finna',
        'fil' => 'filipina',
        'fj' => 'fiĝia',
        'fo' => 'feroa',
        'fr' => 'franca',
        'fy' => 'frisa',
        'ga' => 'irlanda',
        'gd' => 'gaela',
        'gl' => 'galega',
        'gn' => 'gvarania',
        'gu' => 'guĝarata',
        'ha' => 'haŭsa',
        'haw' => 'havaja',
        'he' => 'hebrea',
        'hi' => 'hinda',
        'hr' => 'kroata',
        'ht' => 'haitia kreola',
        'hu' => 'hungara',
        'hy' => 'armena',
        'ia' => 'interlingvao',
        'id' => 'indonezia',
        'ie' => 'okcidentalo',
        'ik' => 'eskima',
        'is' => 'islanda',
        'it' => 'itala',
        'iu' => 'inuita',
        'ja' => 'japana',
        'jv' => 'java',
        'ka' => 'kartvela',
        'kk' => 'kazaĥa',
        'kl' => 'gronlanda',
        'km' => 'kmera',
        'kn' => 'kanara',
        'ko' => 'korea',
        'ks' => 'kaŝmira',
        'ku' => 'kurda',
        'ky' => 'kirgiza',
        'la' => 'latino',
        'lb' => 'luksemburga',
        'ln' => 'lingala',
        'lo' => 'laŭa',
        'lt' => 'litova',
        'lv' => 'latva',
        'mg' => 'malagasa',
        'mi' => 'maoria',
        'mk' => 'makedona',
        'ml' => 'malajalama',
        'mn' => 'mongola',
        'mr' => 'marata',
        'ms' => 'malaja',
        'mt' => 'malta',
        'my' => 'birma',
        'na' => 'naura',
        'nb' => 'dannorvega',
        'ne' => 'nepala',
        'nl' => 'nederlanda',
        'nn' => 'novnorvega',
        'no' => 'norvega',
        'oc' => 'okcitana',
        'om' => 'oroma',
        'or' => 'orijo',
        'pa' => 'panĝaba',
        'pl' => 'pola',
        'ps' => 'paŝtoa',
        'pt' => 'portugala',
        'qu' => 'keĉua',
        'rm' => 'romanĉa',
        'rn' => 'burunda',
        'ro' => 'rumana',
        'ru' => 'rusa',
        'rw' => 'ruanda',
        'sa' => 'sanskrito',
        'sd' => 'sinda',
        'sg' => 'sangoa',
        'sh' => 'serbo-Kroata',
        'si' => 'sinhala',
        'sk' => 'slovaka',
        'sl' => 'slovena',
        'sm' => 'samoa',
        'sn' => 'ŝona',
        'so' => 'somala',
        'sq' => 'albana',
        'sr' => 'serba',
        'ss' => 'svazia',
        'st' => 'sota',
        'su' => 'sunda',
        'sv' => 'sveda',
        'sw' => 'svahila',
        'ta' => 'tamila',
        'te' => 'telugua',
        'tg' => 'taĝika',
        'th' => 'taja',
        'ti' => 'tigraja',
        'tk' => 'turkmena',
        'tl' => 'tagaloga',
        'tlh' => 'klingona',
        'tn' => 'cvana',
        'to' => 'tongaa',
        'tr' => 'turka',
        'ts' => 'conga',
        'tt' => 'tatara',
        'ug' => 'ujgura',
        'uk' => 'ukraina',
        'ur' => 'urduo',
        'uz' => 'uzbeka',
        'vi' => 'vjetnama',
        'vo' => 'volapuko',
        'wo' => 'volofa',
        'xh' => 'ksosa',
        'yi' => 'jida',
        'yo' => 'joruba',
        'za' => 'ĝuanga',
        'zh' => 'ĉina',
        'zu' => 'zulua',
    ],
    'LocalizedNames' => [
        'pt_BR' => 'brazilportugala',
        'pt_PT' => 'eŭropportugala',
        'zh_Hans' => 'ĉina simpligita',
        'zh_Hant' => 'ĉina tradicia',
    ],
];

==> symfony_6.4.25+dfsg.orig.tar.xz: symfony-6.4.25/src/Symfony/Component/Intl/Resources/data/languages/eo.php <==
<?php

return [
    'Names' => [
        'aa' => 'afara',
        'ab' => 'abĥaza',
        'af' => 'afrikansa',
        'am' => 'amhara',
        'ar' => 'araba',
        'as' => 'asama',
        'ay' => 'ajmara',
        'az' => 'azerbajĝana',
        'ba' => 'baŝkira',
        'be' => 'belorusa',
        'bg' => 'bulgara',
        'bi' => 'bislamo',
        'bn' => 'bengala',
        'bo' => 'tibeta',
        'br' => 'bretona',
        'bs' => 'bosna',
        'ca' => 'kataluna',
        'co' => 'korsika',
        'cs' => 'ĉeĥa',
        'cy' => 'kimra',
        'da' => 'dana',
        'de' => 'germana',
        'dv' => 'maldiva',
        'dz' => 'dzonko',
        'efi' => 'ibibioefika',
        'el' => 'greka',
        'en' => 'angla',
        'eo' => 'Esperanto',
        'es' => 'hispana',
        'et' => 'estona',
        'eu' => 'eŭska',
        'fa' => 'persa',
        'fi' => 'finna',
        'fil' => 'filipina',
        'fj' => 'fiĝia',
        'fo' => 'feroa',
        'fr' => 'franca',
        'fy' => 'okcident-frisa',
        'ga' => 'irlanda',
        'gaa' => 'gaa',
        'gd' => 'skot-gaela',
        'gl' => 'galega',
        'gn' => 'gvarania',
        'gu' => 'guĝarata',
        'ha' => 'haŭsa',
        'haw' => 'havaja',
        'he' => 'hebrea',
        'hi' => 'hinda',
        'hr' => 'kroata',
        'ht' => 'haitia kreola',
        'hu' => 'hungara',
        'hy' => 'armena',
        'ia' => 'Interlingvao',
        'id' => 'indonezia',
        'ie' => 'Interlingveo',
        'ik' => 'eskima',
        'is' => 'islanda',
        'it' => 'itala',
        'iu' => 'inuita',
        'ja' => 'japana',
        'jv' => 'java',
        'ka' => 'kartvela',
        'kk' => 'kazaĥa',
        'kl' => 'gronlanda',
        'km' => 'kmera',
        'kn' => 'kanara',
        'ko' => 'korea',
        'ks' => 'kaŝmira',
        'ku' => 'kurda',
        'ky' => 'kirgiza',
        'la' => 'latino',
        'lb' => 'luksemburga',
        'ln' => 'lingala',
        'lo' => 'laŭa',
        'lt' => 'litova',
        'lv' => 'latva',
        'mg' => 'malagasa',
        'mi' => 'maoria',
        'mk' => 'makedona',
        'ml' => 'malajalama',
        'mn' => 'mongola',
        'mr' => 'marata',
        'ms' => 'malaja',
        'mt' => 'malta',
        'my' => 'birma',
        'na' => 'naura',
        'nb' => 'dannorvega',
        'ne' => 'nepala',
        'nl' => 'nederlanda',
        'nn' => 'novnorvega',
        'no' => 'norvega',
        'oc' => 'okcitana',
        'om' => 'oroma',
        'or' => 'orijo',
        'pa' => 'panĝaba',
        'pl' => 'pola',
        'ps' => 'paŝtua',
        'pt' => 'portugala',
        'qu' => 'keĉua',
        'rm' => 'romanĉa',
        'rn' => 'burunda',
        'ro' => 'rumana',
        'ru' => 'rusa',
        'rw' => 'ruanda',
        'sa' => 'sanskrito',
        'sd' => 'sinda',
        'sg' => 'sangoa',
        'sh' => 'serbo-Kroata',
        'si' => 'sinhala',
        'sk' => 'slovaka',
        'sl' => 'slovena',
        'sm' => 'samoa',
        'sn' => 'ŝona',
        'so' => 'somala',
        'sq' => 'albana',
        'sr' => 'serba',
        'ss' => 'svazia',
        'st' => 'sota',
        'su' => 'sunda',
        'sv' => 'sveda',
        'sw' => 'svahila',
        'ta' => 'tamila',
        'te' => 'telugua',
        'tg' => 'taĝika',
        'th' => 'taja',
        'ti' => 'tigraja',
        'tk' => 'turkmena',
        'tl' => 'tagaloga',
        'tlh' => 'klingona',
        'tn' => 'cvana',
        'to' => 'tongana',
        'tr' => 'turka',
        'ts' => 'conga',
        'tt' => 'tatara',
        'ug' => 'ujgura',
        'uk' => 'ukraina',
        'ur' => 'urduo',
        'uz' => 'uzbeka',
        'vi' => 'vjetnama',
        'vo' => 'Volapuko',
        'wo' => 'volofa',
        'xh' => 'ksosa',
        'yi' => 'jida',
        'yo' => 'joruba',
        'za' => 'ĝuanga',
        'zh' => 'ĉina',
        'zu' => 'zulua',
    ],
    'LocalizedNames' => [
        'pt_BR' => 'portugala brazila',
        'pt_PT' => 'portugala eŭropa',
        'zh_Hans' => 'ĉina simpligita',
        'zh_Hant' => 'ĉina tradicia',
    ],
];
